@@ -6,7 +6,7 @@ use warnings;
 BEGIN { unshift @INC, ($ENV{'PERL5LIB'} =~ m/([^:]+)/g); }
 
 
-use MyApp::Service::Flood;
+use Beekeeper::Client;
 use Time::HiRes qw( time sleep );
 use Getopt::Long;
 
@@ -35,15 +35,15 @@ Flood with requests a test worker pool.
   -b, --benchmark  run a set of predefined benchmarks
   -h, --help       display this help and exit
 
-Create a burst of 5000 notifications:
+To create a burst of 5000 notifications:
 
   flood --type N --count 5000
 
-Create a constant load of 100 requests per second:
+To create a constant load of 100 requests per second:
 
   flood --type S --rate 100
 
-Run a predefined set of benchmarks:
+Run a predefined set of benchmarks
 
   flood --benchmark
 
@@ -86,34 +86,43 @@ sub time_this {
     my $payload = { data => 'X' x ($size * 1024) };
 
     my $type = $args{'type'} || 'N';
+    my @async_calls;
     my $code;
 
     if ($type =~ m/^N(otification)?/i) {
         $type = 'notifications';
         $code = sub {
-            # Measure send time
-            MyApp::Service::Flood->notify( $payload );
+            $client->send_notification(
+                method => 'myapp.test.flood', 
+                params => $payload,
+            );
         };
     }
     elsif ($type =~ m/^S(ync)?/i) {
         $type = 'sync calls';
         $code = sub {
-            # Measure response time
-            MyApp::Service::Flood->echo( $payload );
+            $client->call_remote(
+                method => 'myapp.test.echo', 
+                params => $payload,
+            );
         };
     }
     elsif ($type =~ m/^A(sync)?/i) {
         $type = 'async calls';
         $code = sub {
-            # Measure send time only
-            MyApp::Service::Flood->async_echo( $payload, sub {} );
+            push @async_calls, $client->call_remote_async(
+                method => 'myapp.test.echo', 
+                params => $payload,
+            );
         };
     }
     elsif ($type =~ m/^F(ire)?/i) {
         $type = 'fire & forget';
         $code = sub {
-            # Measure send time only
-            MyApp::Service::Flood->fire_echo( $payload );
+            $client->fire_remote(
+                method => 'myapp.test.echo', 
+                params => $payload,
+            );
         };
     }
     else {
@@ -157,6 +166,11 @@ sub time_this {
         }
     }
 
+    if ($type eq 'async call') {
+        $client->wait_async_calls;
+        @async_calls = ();
+    }
+
     my $ellapsed = time() - $start - $sleept;
     my $took = sprintf("%.3f", $ellapsed);
     my $tps = sprintf("%.0f", $count / $ellapsed);
@@ -164,8 +178,6 @@ sub time_this {
 
     printf( "%s %-15s of %3s Kb  ", $count, $type, $size ) if ($rate);
     printf( "in %6s sec  %6s /sec %6s ms each\n", $took, $tps, $avg );
-
-    $client->wait_async_calls if ($type eq 'async calls');
 }
 
 sub run_benchmarks {
