@@ -3,7 +3,7 @@ package Beekeeper::WorkerPool;
 use strict;
 use warnings;
 
-our $VERSION = '0.06';
+our $VERSION = '0.04';
 
 use base 'Beekeeper::WorkerPool::Daemon';
 use POSIX ":sys_wait_h";
@@ -105,8 +105,9 @@ sub main {
     my $pool_id        = $self->{config}->{'pool_id'};
 
     my @spawn_workers = (
-        # Every pool spawns a Supervisor worker
+        # Every pool spawns at least a Supervisor and a Sinkhole
         'Beekeeper::Service::Supervisor::Worker',
+        'Beekeeper::Service::Sinkhole::Worker',
     );
 
     if ($self->{config}->{'use_toybroker'}) {
@@ -143,10 +144,10 @@ sub main {
     # Install signal handlers to control this daemon and forked workers.
     # The supported signals and related actions are:
     #
-    # TERM  tell workers to quit after finishing their current tasks, then quit
-    # INT   tell workers to quit immediately (even in the middle of a task), then quit
+    # TERM  tell workers to quit after finishing their current jobs, then quit
+    # INT   tell workers to quit immediately (even in the middle of a job), then quit
     # PWR   received when system is being shut down, it is handled the same as TERM
-    # HUP   restart workers after finishing their current tasks
+    # HUP   restart workers after finishing their current jobs
 
     my $mode = '';
 
@@ -360,7 +361,7 @@ Beekeeper::WorkerPool - Manage worker pools
 
 =head1 VERSION
  
-Version 0.06
+Version 0.04
 
 =head1 SYNOPSIS
 
@@ -382,12 +383,12 @@ Version 0.06
 
 =head1 DESCRIPTION
 
-This module contains the core of the command line tool L<bkpr> which is used
+This module contains the core of the command line tool C<bkpr> which is used
 to manage worker pools: it start, stop and monitor pools of persistent
-L<Beekeeper::Worker> processes which receive RPC requests from message bus.
+C<Beekeeper::Worker> processes which receive RPC requests from message bus.
 
 When started it daemonize itself (unless C<--foreground> option is passed) and
-fork all worker processes, then monitor those forked processes and immediately
+fork all worker processes, then monitor those forked processes and B<immediately>
 respawn defunct ones.
 
 =head1 CONFIGURATION
@@ -449,6 +450,7 @@ The following example defines the logical bus "backend":
       "host"   : "10.0.0.1",
       "user"   : "username",
       "pass"   : "password",
+      "vhost"  : "/backend",
   }]
 
 =head1 AUTHOR
