@@ -11,12 +11,11 @@ my $bus_config_json = qq<
 
 [
     {
-        "bus-id"  : "test",
-        "host"    : "localhost",
-        "user"    : "test",
-        "pass"    : "abc123",
-        "vhost"   : "/test",
-        "default" : 1,
+        "bus_id"   : "test",
+        "host"     : "localhost",
+        "port"     :  %PORT%,
+        "username" : "test",
+        "password" : "abc123",
     },
 ]>;
 
@@ -24,14 +23,18 @@ my $toybroker_config_json = qq<
 
 # Mock toybroker.config.json file used by tests
 
-{
-    "listen_addr" : "127.0.0.1",
-    "listen_port" : "61613",
+[
+    {
+        "listen_addr" : "127.0.0.1",
+        "listen_port" : %PORT%,
 
-    "users" : {
-        "test" : { "password" : "abc123" },
+        "users" : {
+            "test" : { "password" : "abc123" },
+        },
     },
-}>;
+]>;
+
+my $TEST_PORT;
 
 sub read_config_file {
     my ($class, $file) = @_;
@@ -39,6 +42,13 @@ sub read_config_file {
     my $data = $file eq "bus.config.json"       ? $bus_config_json       : 
                $file eq "toybroker.config.json" ? $toybroker_config_json : '';
 
+    unless ($TEST_PORT) {
+        #TODO: Find an unused port
+        $TEST_PORT = 50000 + int(rand(10000));
+    }
+
+    $data =~ s/%PORT%/$TEST_PORT/;
+
     # Allow comments and end-comma
     my $json = JSON::XS->new->relaxed;
 
